[Piglit] [PATCH 6/7] astc_3d: Add an assert for texture depth
Anuj Phogat
anuj.phogat at gmail.com
Mon Aug 1 22:16:19 UTC 2016
Also update the comment reflecting texture depth.
Cc: Nanley Chery <nanley.g.chery at intel.com>
Signed-off-by: Anuj Phogat <anuj.phogat at gmail.com>
---
.../oes_compressed_astc-miptree-3d.c | 9 +++++----
1 file changed, 5 insertions(+), 4 deletions(-)
diff --git a/tests/spec/oes_texture_compression_astc/oes_compressed_astc-miptree-3d.c b/tests/spec/oes_texture_compression_astc/oes_compressed_astc-miptree-3d.c
index dd41696..d743f3c 100644
--- a/tests/spec/oes_texture_compression_astc/oes_compressed_astc-miptree-3d.c
+++ b/tests/spec/oes_texture_compression_astc/oes_compressed_astc-miptree-3d.c
@@ -27,10 +27,10 @@
*
* The files under compressed/3D/{hdr, ldrl, ldrs} contain full miptrees, in
* the GL_*_ASTC_* formats, of a 3D texture of waffles and fruit [1]. The base
* level size was shrunken to 160x106 pixels. The files under the
* decompressed/3D/{hdr, ldrl, ldrs} directory contain the same miptree in
* GL_RGBA format. Each miplevel was obtained by decompressing the
* corresponding ASTC texture with astcenc [2].
*
* This test draws miplevels of the compressed textures in a space-efficient
* manner. It does the same when drawing the decompressed texture on the right.
@@ -146,6 +146,7 @@ load_texture(const char *dir1, const char *dir2,
assert(info->target == GL_TEXTURE_3D);
assert(info->pixel_width == LEVEL0_WIDTH);
assert(info->pixel_height == LEVEL0_HEIGHT);
+ assert(info->pixel_depth == LEVEL0_DEPTH);
*tex_name = 0;
ok = piglit_ktx_load_texture(ktx, tex_name, NULL);
@@ -27,10 +27,10 @@
* The files under compressed/3D/{hdr, ldrl, ldrs} contain full miptrees, in
* the GL_*_ASTC_* formats, of a 3D texture of waffles and fruit [1]. The base
- * level size was shrunken to 160x106 pixels. The files under the
- * decompressed/3D/{hdr, ldrl, ldrs} directory contain the same miptree in
- * GL_RGBA format. Each miplevel was obtained by decompressing the
- * corresponding ASTC texture with astcenc [2].
+ * level size was shrunken to 160x106 pixels and used to create a 3D texture
+ * with depth=8. The files under the decompressed/3D/{hdr, ldrl, ldrs} directory
+ * contain the same miptree in GL_RGBA format. Each miplevel was obtained by
+ * decompressing the corresponding ASTC texture with astcenc [2].
*
* This test draws miplevels of the compressed textures in a space-efficient
--
2.5.5
More information about the Piglit
mailing list